
Authors
=======

* Pierre-Luc St-Charles - stcharpl<at>crim.ca
* Francis Charette Migneault - francis.charette-migneault<at>crim.ca
* Mario Beaulieu - mario.beaulieu<at>crim.ca
* Justine Boulent - justine.boulent<at>usherbrooke.ca
